@@ -7,19 +7,18 @@
 
   \author Satofumi KAMIMURA
 
-  $Id$
+  $Id: ClockPartsDraw.h 297 2014-03-03 09:54:51Z satofumi $
 */
 
 #include <QVector>
 
 class QPainter;
 class QPoint;
-class QRegion;
 class ThemeResource;
 
 
-namespace ClockPartsDraw {
-
+namespace ClockPartsDraw
+{
   enum {
     InvalidCellIndex = -1,      //!< 無効なセル番号
     NoAnimationCell = -2,       //!< セルを描画しない場合
@@ -28,15 +27,13 @@ namespace ClockPartsDraw {
   /*!
     \brief テーマ時計の再描画を行う
 
-    \param region [o] 描画 Pixel マスク領域の和
-    \param resource [i] 描画リソース
-    \param digital_positions [i] デジタル部品の描画位置
-    \param calendar_positions [i] カレンダー部品の表示位置
-    \param scaling_percent [i] 拡大率 [%]
-    \param sec_offset [i] 描画時の秒オフセット [sec]
+    \param[in] resource 描画リソース
+    \param[in] digital_positions デジタル部品の描画位置
+    \param[in] calendar_positions カレンダー部品の表示位置
+    \param[in] scaling_percent 拡大率 [%]
+    \param[in] sec_offset 描画時の秒オフセット [sec]
   */
-  extern void updatePixmaps(QRegion& region,
-                            const ThemeResource& resource,
+  extern void updatePixmaps(const ThemeResource& resource,
                             const QVector<QPoint>& digital_positions,
                             const QVector<QPoint>& calendar_positions,
                             size_t scaling_percent = 100, int sec_offset = 0,
@@ -45,9 +42,9 @@ namespace ClockPartsDraw {
   /*!
     \brief Pixel 画像の描画
 
-    \param painter [i] 描画対象
+    \param[in] painter 描画対象
   */
   extern void drawPixmaps(QPainter& painter, bool force_draw = false);
-};
+}
 
 #endif /* !CLOCK_PARTS_DRAW_H */
