@@ -7,30 +7,24 @@
 
   \author Satofumi KAMIMURA
 
-  $Id$
+  $Id: RrdaResource.h 276 2009-10-22 03:44:32Z satofumi $
 */
 
+#include <fstream>
 #include <memory>
 
 
 /*!
   \brief RRDA のリソース管理
 */
-class RrdaResource {
-
-  RrdaResource(void);
-  RrdaResource(const RrdaResource& rhs);
-  RrdaResource& operator = (const RrdaResource& rhs);
-
-  struct pImpl;
-  std::auto_ptr<pImpl> pimpl;
-
+class RrdaResource
+{
 public:
   /*!
     \brief コンストラクタ
 
-    \param fin [i] 圧縮ファイル位置の読み出しストリーム
-    \param size [i] 圧縮ファイルのサイズ
+    \param[in] fin 圧縮ファイル位置の読み出しストリーム
+    \param[in] size 圧縮ファイルのサイズ
   */
   explicit RrdaResource(std::ifstream& fin, size_t size);
   ~RrdaResource(void);
@@ -39,11 +33,19 @@ public:
   /*!
     \brief メモリの先頭アドレスを返す
 
-    \param size [o] リソースのサイズ [byte]
+    \param[out] size リソースのサイズ [byte]
 
     \return メモリの先頭アドレス
   */
   unsigned char* get(size_t* size = NULL);
+
+private:
+  RrdaResource(void);
+  RrdaResource(const RrdaResource& rhs);
+  RrdaResource& operator = (const RrdaResource& rhs);
+
+  struct pImpl;
+  std::auto_ptr<pImpl> pimpl;
 };
 
 #endif /* !RRDA_RESOURCE_H */
