@@ -4,28 +4,32 @@
 
   \author Satofumi KAMIMURA
 
-  $Id$
+  $Id: SettingConfig.cpp 270 2009-09-07 15:27:15Z satofumi $
 */
 
+#include "SettingConfig.h"
+#include "AnimationPattern.h"
 #include <QVector>
 #include <QXmlDefaultHandler>
 #include <fstream>
-#include "SettingConfig.h"
-#include "AnimationPattern.h"
+
+using namespace std;
 
 
-namespace {
+namespace
+{
+  typedef QMap<string, string> TagMap;
 
-  typedef QMap<std::string, std::string> TagMap;
-
-  class XmlHandler : public QXmlDefaultHandler {
+  class XmlHandler : public QXmlDefaultHandler
+  {
     QString current_text_;
     QVector<QString> tag_stack_;
     TagMap& tag_map_;
 
   public:
 
-    XmlHandler(TagMap& tags) : tag_map_(tags) {
+    XmlHandler(TagMap& tags) : tag_map_(tags)
+    {
     }
 
 
@@ -33,7 +37,8 @@ namespace {
     bool startElement(const QString& namespaceURI,
                       const QString& localName,
                       const QString& qName,
-                      const QXmlAttributes& attributes) {
+                      const QXmlAttributes& attributes)
+    {
       static_cast<void>(namespaceURI);
       static_cast<void>(localName);
       static_cast<void>(attributes);
@@ -48,7 +53,8 @@ namespace {
     // 要素の終了
     bool endElement(const QString& namespaceURI,
                     const QString& localName,
-                    const QString& qName) {
+                    const QString& qName)
+    {
       static_cast<void>(namespaceURI);
       static_cast<void>(localName);
       static_cast<void>(qName);
@@ -58,7 +64,6 @@ namespace {
 
       // 前後の空白を除去して空になったら、終端とみなして何もしない
       if (! value.isEmpty()) {
-
         QString key;
         for (QVector<QString>::const_iterator it = tag_stack_.begin();
              it != tag_stack_.end(); ++it) {
@@ -80,32 +85,34 @@ namespace {
 
 
     // タグの取得
-    bool characters(const QString& str) {
+    bool characters(const QString& str)
+    {
       current_text_ += str;
       return true;
     }
 
 
     // エラー処理
-    bool fatalError(const QXmlParseException& exception) {
+    bool fatalError(const QXmlParseException& exception)
+    {
       static_cast<void>(exception);
 
       // XML のデータ末尾に不正なデータがあっても読み飛ばせるように、false
       return false;
     }
   };
-};
+}
 
 
-struct SettingConfig::pImpl {
-
-  std::string config_file_;
+struct SettingConfig::pImpl
+{
+  string config_file_;
   TagMap tags_;
 
 
-  pImpl(const std::string& config_file)
-    : config_file_(config_file) {
-
+  pImpl(const string& config_file)
+    : config_file_(config_file)
+  {
     // デフォルトパラメータの設定
     setDefaults();
 
@@ -114,21 +121,21 @@ struct SettingConfig::pImpl {
   }
 
 
-  pImpl(TagMap& tags, QByteArray& data) {
-
+  pImpl(TagMap& tags, QByteArray& data)
+  {
     // private メンバに対する処理結果が返されるようにする
-    std::swap(tags_, tags);
+    swap(tags_, tags);
 
     // 読み出し
     load(data);
 
-    std::swap(tags, tags_);
+    swap(tags, tags_);
   }
 
 
   // デフォルト値の設定
-  void setDefaults(void) {
-
+  void setDefaults(void)
+  {
     // ベース画像
     tags_.insert("base/base_org", "base");
 
@@ -176,6 +183,7 @@ struct SettingConfig::pImpl {
     tags_.insert("calendar/separator", "separator");
     tags_.insert("calendar/week", "week");
     tags_.insert("calendar/month", "on");
+    tags_.insert("calendar/zero", "on");
 
     tags_.insert("calendar/m1_xpos", "0");
     tags_.insert("calendar/m1_ypos", "0");
@@ -200,16 +208,16 @@ struct SettingConfig::pImpl {
 
 
   // 読み出し
-  bool load(std::string& file) {
-
-    std::ifstream fin(file.c_str());
+  bool load(string& file)
+  {
+    ifstream fin(file.c_str());
     if (! fin.is_open()) {
       return false;
     }
 
     // 全内容のデータを作成する
     QString all_lines;
-    std::string line;
+    string line;
     while (getline(fin, line)) {
       all_lines += line.c_str();
     }
@@ -221,8 +229,8 @@ struct SettingConfig::pImpl {
 
 
   // 読み出し
-  bool load(QByteArray& data) {
-
+  bool load(QByteArray& data)
+  {
     QXmlInputSource xml_resource;
     xml_resource.setData(data);
     return loadXml(xml_resource);
@@ -230,8 +238,8 @@ struct SettingConfig::pImpl {
 
 
   // XML の読み出し処理
-  bool loadXml(QXmlInputSource& xml_resource) {
-
+  bool loadXml(QXmlInputSource& xml_resource)
+  {
     // XML 内容の読み出し
     XmlHandler xml_handler(tags_);
     QXmlSimpleReader reader;
@@ -245,22 +253,22 @@ struct SettingConfig::pImpl {
 
 
   // 保存
-  bool save(std::string& file) {
-
-    std::ofstream fout(file.c_str());
+  bool save(string& file)
+  {
+    ofstream fout(file.c_str());
     if (! fout.is_open()) {
       return false;
     }
 
-    fout << "<?xml version=\"1.0\"?>" << std::endl
-         << "<lm_tmclock>" << std::endl;
+    fout << "<?xml version=\"1.0\"?>" << endl
+         << "<lm_tmclock>" << endl;
 
     // ベース情報
     const char* base_tags[] = { "base_org" };
     size_t n = sizeof(base_tags) / sizeof(base_tags[0]);
     writeTagValues(fout, "base", base_tags, n);
 
-    fout << std::endl;
+    fout << endl;
 
     // アナログ情報
     const char* analog_tags[] = {
@@ -271,7 +279,7 @@ struct SettingConfig::pImpl {
     n = sizeof(analog_tags) / sizeof(analog_tags[0]);
     writeTagValues(fout, "analog", analog_tags, n);
 
-    fout << std::endl;
+    fout << endl;
 
     // デジタル情報
     const char* digital_tags[] = {
@@ -285,12 +293,12 @@ struct SettingConfig::pImpl {
     n = sizeof(digital_tags) / sizeof(digital_tags[0]);
     writeTagValues(fout, "digital", digital_tags, n);
 
-    fout << std::endl;
+    fout << endl;
 
     // カレンダー情報
     const char* calendar_tags[] = {
       "number", "separator", "week",
-      "month",
+      "month", "zero",
       "m1_xpos", "m1_ypos", "m2_xpos", "m2_ypos",
       "d1_xpos", "d1_ypos", "d2_xpos", "d2_ypos",
       "we_xpos", "we_ypos",
@@ -299,7 +307,7 @@ struct SettingConfig::pImpl {
     n = sizeof(calendar_tags) / sizeof(calendar_tags[0]);
     writeTagValues(fout, "calendar", calendar_tags, n);
 
-    fout << std::endl;
+    fout << endl;
 
     // 追加画像
     const char* additional_tags[] = {
@@ -312,17 +320,17 @@ struct SettingConfig::pImpl {
     // アニメーション情報
     writeAnimationTags(fout);
 
-    fout << "<lm_tmclock" << std::endl;
+    fout << "<lm_tmclock" << endl;
 
     return true;
   }
 
 
   // タグと値の書き出し
-  void writeTagValues(std::ofstream& fout,
-                      const char* base, const char* tags[], size_t n) {
-
-    fout << "  <" << base << ">" << std::endl;
+  void writeTagValues(ofstream& fout,
+                      const char* base, const char* tags[], size_t n)
+  {
+    fout << "  <" << base << ">" << endl;
 
     for (size_t i = 0; i < n; ++i) {
       const char* tag = tags[i];
@@ -330,17 +338,17 @@ struct SettingConfig::pImpl {
 
       fout << "    <" << tag << ">"
            << " " << tags_[key.toStdString()] << " "
-           << "</" << tag << ">" << std::endl;
+           << "</" << tag << ">" << endl;
     }
 
-    fout << "  </" << base << ">" << std::endl;
+    fout << "  </" << base << ">" << endl;
   }
 
 
   // アニメーション情報
-  void writeAnimationTags(std::ofstream& fout) {
-
-    fout << "  <animation>" << std::endl;
+  void writeAnimationTags(ofstream& fout)
+  {
+    fout << "  <animation>" << endl;
 
     // !!! ThemeConfigWindow と共通にすべき
     enum {
@@ -356,17 +364,17 @@ struct SettingConfig::pImpl {
       }
 
       // 書き出し処理
-      fout << "    <" << tag_names.simple_tag << ">" << std::endl;
-      fout << "      <cell> " << p.value() << " </cell>" << std::endl;
+      fout << "    <" << tag_names.simple_tag << ">" << endl;
+      fout << "      <cell> " << p.value() << " </cell>" << endl;
 
       fout << "      <xpos> " << tags_[tag_names.xpos_tag] << " </xpos>"
-           << std::endl;
+           << endl;
       fout << "      <ypos> " << tags_[tag_names.ypos_tag] << " </ypos>"
-           << std::endl;
+           << endl;
 
-      fout << "    </" << tag_names.simple_tag << ">" << std::endl;
+      fout << "    </" << tag_names.simple_tag << ">" << endl;
     }
-    fout << std::endl;
+    fout << endl;
 
     // パターン情報
     for (size_t i = 0; i < AnimationCellMax; ++i) {
@@ -381,49 +389,52 @@ struct SettingConfig::pImpl {
       // 書き出し処理
       double probability = atof(tags_[tag_names.probability_tag].c_str());
       size_t cycle = atoi(tags_[tag_names.cycle_tag].c_str());
-      std::string pattern = tags_[tag_names.pattern_tag];
+      string pattern = tags_[tag_names.pattern_tag];
 
-      fout << "    <" << tag_names.simple_tag << ">" << std::endl;
+      fout << "    <" << tag_names.simple_tag << ">" << endl;
       fout << "      <probability> " << probability << " </probability>"
-           << std::endl;
-      fout << "      <cycle> " << cycle << " </cycle>" << std::endl;
-      fout << "      <pattern> " << pattern << " </pattern>" << std::endl;
+           << endl;
+      fout << "      <cycle> " << cycle << " </cycle>" << endl;
+      fout << "      <pattern> " << pattern << " </pattern>" << endl;
 
-      fout << "    </" << tag_names.simple_tag << ">" << std::endl;
-      fout << std::endl;
+      fout << "    </" << tag_names.simple_tag << ">" << endl;
+      fout << endl;
     }
 
-    fout << "  </animation>" << std::endl;
+    fout << "  </animation>" << endl;
   }
 };
 
 
-SettingConfig::SettingConfig(const std::string& config_file)
-  : pimpl(new pImpl(config_file)) {
+SettingConfig::SettingConfig(const string& config_file)
+  : pimpl(new pImpl(config_file))
+{
 }
 
 
-SettingConfig::SettingConfig(QMap<std::string, std::string>& tags,
+SettingConfig::SettingConfig(QMap<string, string>& tags,
                              QByteArray& data)
-  : pimpl(new pImpl(tags, data)) {
+  : pimpl(new pImpl(tags, data))
+{
 }
 
 
-SettingConfig::~SettingConfig(void) {
+SettingConfig::~SettingConfig(void)
+{
 }
 
 
 // 値の読み出し
-const std::string SettingConfig::getValue(const std::string& tag) {
-
+const string SettingConfig::getValue(const string& tag)
+{
   TagMap::iterator p = pimpl->tags_.find(tag.c_str());
   return (p != pimpl->tags_.end()) ? p.value() : "";
 }
 
 
 // 値の書き込み
-void SettingConfig::setValue(const std::string& tag, const std::string& value) {
-
+void SettingConfig::setValue(const string& tag, const string& value)
+{
   TagMap::iterator p = pimpl->tags_.find(tag.c_str());
   if (p == pimpl->tags_.end()) {
     // 存在しないタグは、登録させない
@@ -436,7 +447,7 @@ void SettingConfig::setValue(const std::string& tag, const std::string& value) {
 
 
 // 保存
-void SettingConfig::save(void) {
-
+void SettingConfig::save(void)
+{
   pimpl->save(pimpl->config_file_);
 }
