@@ -4,7 +4,7 @@
 
   \author Satofumi KAMIMURA
 
-  $Id: ThemeClockDraw.cpp 270 2009-09-07 15:27:15Z satofumi $
+  $Id: ThemeClockDraw.cpp 297 2014-03-03 09:54:51Z satofumi $
 
   \todo エラーメッセージの処理
   \todo 時刻毎のベース画像切替え機能を実装する
@@ -21,7 +21,6 @@
 #include "split.h"
 #include <QLabel>
 #include <QVBoxLayout>
-#include <QRegion>
 #include <QBitmap>
 #include <QCloseEvent>
 #include <QPainter>
@@ -71,6 +70,7 @@ struct ThemeClockDraw::pImpl
   vector<AnimationPattern> patterns_;
   QTimer animation_cycle_timer_;
 
+
   pImpl(ThemeClockDraw* parent)
     : message_label_(NULL), theme_loaded_(false), parent_widget_(NULL),
       scaling_percent_(100), no_animation_(false), sec_offset_(0),
@@ -492,10 +492,6 @@ struct ThemeClockDraw::pImpl
     // オプション設定の更新
     theme_resource_.option = option;
 
-    // アニメーション情報の読み出し
-    // !!! loadAnimations(theme_resource_, tags, rrda_encoder);
-    // !!!
-
     theme_loaded_ = true;
 
     return true;
@@ -582,21 +578,13 @@ void ThemeClockDraw::redraw(int sec_offset, QWidget* parent, int cell_index)
   if (pimpl->theme_loaded_) {
 
     // 描画する pixmap を評価し、mask を生成する
-    QRegion region;
-    ClockPartsDraw::updatePixmaps(region,
-                                  pimpl->theme_resource_,
+    ClockPartsDraw::updatePixmaps(pimpl->theme_resource_,
                                   pimpl->digital_positions_,
                                   pimpl->calendar_positions_,
                                   pimpl->scaling_percent_,
                                   sec_offset, cell_index);
 
-    // mask を適用する。mask によっては、この時点で paintEvent() が呼ばれる
-    if (parent) {
-      parent->setMask(region);
-    }
-
     // paintEvent() が呼ばれなかったとき用
-    // もし、setMask() 時に paintEvent() が呼ばれていた場合、処理はすぐに戻る
     update();
   }
 }
