@@ -7,51 +7,26 @@
 
   \author Satofumi KAMIMURA
 
-  $Id$
+  $Id: ThemeClockDraw.h 276 2009-10-22 03:44:32Z satofumi $
 */
 
-#include <QWidget>
 #include "ClockPartsDraw.h"
+#include <QWidget>
+#include <memory>
 
 
 /*!
   \brief テーマ時計の描画クラス
 */
-class ThemeClockDraw : public QWidget {
+class ThemeClockDraw : public QWidget
+{
   Q_OBJECT;
 
-  ThemeClockDraw(const ThemeClockDraw& rhs);
-  ThemeClockDraw& operator = (const ThemeClockDraw& rhs);
-
-  struct pImpl;
-  std::auto_ptr<pImpl> pimpl;
-
-private slots:
-  void evaluateAnimation(void);
-  void updateCell(int index);
-
-protected:
-
-  /*!
-    \brief 描画イベント処理
-
-    \param event [i/o] イベント
-  */
-  void paintEvent(QPaintEvent* event);
-
-
-  /*!
-    \brief Qt のクローズイベント
-
-    \param event [i/o] イベント
-  */
-  void closeEvent(QCloseEvent* event);
-
 public:
   /*!
     \brief コンストラクタ
 
-    \param parent [i] 親ウィジット
+    \param[in] parent 親ウィジット
   */
   ThemeClockDraw(QWidget* parent = 0);
   ~ThemeClockDraw(void);
@@ -60,8 +35,8 @@ public:
   /*!
     \brief テーマファイルの読み出し
 
-    \param theme_file [i] テーマファイル
-    \param key [i] RRDA キー
+    \param[in] theme_file テーマファイル
+    \param[in] key RRDA キー
 
     \retval true 成功
     \retval エラー
@@ -94,9 +69,9 @@ public:
   /*!
     \brief テーマ時計の再描画を行う
 
-    \param sec_offset [i] 描画時間のオフセット [秒]
-    \param parent [i] 親ウィジット
-    \param cell_index [i] 描画するアニメーションセル
+    \param[in] sec_offset 描画時間のオフセット [秒]
+    \param[in] parent 親ウィジット
+    \param[in] cell_index 描画するアニメーションセル
   */
   void redraw(int sec_offset = 0, QWidget* parent = NULL,
               int cell_index = ClockPartsDraw::InvalidCellIndex);
@@ -113,22 +88,54 @@ public:
   /*!
     \brief 描画の拡大率を設定
 
-    \param percent [i] 描画の拡大率
+    \param[in] percent 描画の拡大率
   */
   void updateScalingPercent(size_t percent);
 
+
   /*!
     \brief アニメーション する / しない の設定
 
-    \param on [i] アニメーションするとき true
+    \param[in] on アニメーションするとき true
   */
   void setAnimationOn(bool on);
 
+
 signals:
   /*!
     \brief 終了シグナルを投げる
   */
   void previewClose(void);
+
+
+protected:
+  /*!
+    \brief 描画イベント処理
+
+    \param[in,out] event イベント
+  */
+  void paintEvent(QPaintEvent* event);
+
+
+  /*!
+    \brief Qt のクローズイベント
+
+    \param[in,out] event イベント
+  */
+  void closeEvent(QCloseEvent* event);
+
+
+private slots:
+  void evaluateAnimation(void);
+  void updateCell(int index);
+
+
+private:
+  ThemeClockDraw(const ThemeClockDraw& rhs);
+  ThemeClockDraw& operator = (const ThemeClockDraw& rhs);
+
+  struct pImpl;
+  std::auto_ptr<pImpl> pimpl;
 };
 
 #endif /*! THEME_CLOCK_DRAW_H */
