@@ -7,17 +7,18 @@
 
   \author Satofumi KAMIMURA
 
-  $Id$
+  $Id: ArchiveConfig.h 262 2009-01-30 13:25:37Z satofumi $
 */
 
 #include <memory>
+#include <string>
 
 
 /*!
   \brief 設定ファイルの管理クラス
 */
-class ArchiveConfig {
-
+class ArchiveConfig
+{
   ArchiveConfig(void);
   ArchiveConfig(const ArchiveConfig& rhs);
   ArchiveConfig& operator = (const ArchiveConfig& rhs);
@@ -30,7 +31,7 @@ class ArchiveConfig {
   /*!
     \brief コンストラクタ
 
-    \param archive_file [i] 読み出すファイル名
+    \param[in] archive_file 読み出すファイル名
   */
   explicit ArchiveConfig(const std::string& archive_file);
   ~ArchiveConfig(void);
@@ -55,7 +56,7 @@ class ArchiveConfig {
   /*!
     \brief リリースファイル名の設定
 
-    \param release_file [i] リリースファイル名
+    \param[in] release_file リリースファイル名
   */
   void setReleaseName(const std::string& release_file);
 
@@ -71,7 +72,7 @@ class ArchiveConfig {
   /*!
     \brief RRDA キー
 
-    \param rrda_key [i] RRDA キー
+    \param[in] rrda_key RRDA キー
   */
   void setRrdaKey(const std::string& rrda_key);
 
@@ -79,7 +80,7 @@ class ArchiveConfig {
   /*!
     \brief データ名の取得
 
-    \param key [i] キー
+    \param[in] key キー
 
     \retval データファイル名
   */
@@ -89,8 +90,8 @@ class ArchiveConfig {
   /*!
     \brief データ名の設定
 
-    \param key [i] キー
-    \param name [i] データファイル名
+    \param[in] key キー
+    \param[in] name データファイル名
   */
   void setNormalData(const std::string& key, const std::string& name);
 
@@ -98,7 +99,7 @@ class ArchiveConfig {
   /*!
     \brief データ名の取得 (制限データ)
 
-    \param key [i] キー
+    \param[in] key キー
 
     \retval データファイル名
   */
@@ -108,8 +109,8 @@ class ArchiveConfig {
   /*!
     \brief データ名の設定 (制限データ)
 
-    \param key [i] キー
-    \param name [i] データファイル名
+    \param[in] key キー
+    \param[in] name データファイル名
   */
   void setRestrictData(const std::string& key, const std::string& name);
 
@@ -126,7 +127,7 @@ class ArchiveConfig {
   /*!
     \brief アーカイブファイル名を変更して更新
 
-    \param name [i] アーカイブファイル名
+    \param[in] name アーカイブファイル名
 
     \retval true 正常
     \retval false エラー
