@@ -7,16 +7,18 @@
 
   \author Satofumi KAMIMURA
 
-  $Id$
+  $Id: CellPreviewWidget.h 262 2009-01-30 13:25:37Z satofumi $
 */
 
 #include <QWidget>
+#include <memory>
 
 
 /*!
   \brief セルのプレビュー用ウィジット
 */
-class CellPreviewWidget : public QWidget {
+class CellPreviewWidget : public QWidget
+{
   Q_OBJECT;
 
   CellPreviewWidget(const CellPreviewWidget& rhs);
@@ -29,7 +31,7 @@ public:
   /*!
     \brief コンストラクタ
 
-    \param parent [i] 親ウィジット
+    \param[in] parent 親ウィジット
   */
   CellPreviewWidget(QWidget* parent = 0);
   ~CellPreviewWidget(void);
