@@ -4,30 +4,25 @@
 
   \author Satofumi KAMIMURA
 
-  $Id$
+  $Id: PartsPlaceScene.cpp 263 2009-01-30 14:48:10Z satofumi $
 */
 
-#include <QGraphicsSceneMouseEvent>
 #include "PartsPlaceScene.h"
+#include <QGraphicsSceneMouseEvent>
 
 
-struct PartsPlaceScene::pImpl {
-
-  // !!!
-};
-
-
-PartsPlaceScene::PartsPlaceScene(QObject* parent)
-  : QGraphicsScene(parent), pimpl(new pImpl) {
+PartsPlaceScene::PartsPlaceScene(QObject* parent) : QGraphicsScene(parent)
+{
 }
 
 
-PartsPlaceScene::~PartsPlaceScene(void) {
+PartsPlaceScene::~PartsPlaceScene(void)
+{
 }
 
 
-void PartsPlaceScene::mousePressEvent(QGraphicsSceneMouseEvent *mouseEvent) {
-
+void PartsPlaceScene::mousePressEvent(QGraphicsSceneMouseEvent *mouseEvent)
+{
   if (mouseEvent->button() != Qt::LeftButton) {
     // 左クリック以外ならば、戻る
     return;
@@ -35,9 +30,7 @@ void PartsPlaceScene::mousePressEvent(QGraphicsSceneMouseEvent *mouseEvent) {
 
   // クリック位置を取得
   QPointF point = mouseEvent->scenePos();
-  //fprintf(stderr, "%f, %f\n", point.x(), point.y());
 
   // シグナルを投げる
   emit clicked(static_cast<int>(point.x()), static_cast<int>(point.y()));
 }
-
