@@ -4,18 +4,20 @@
 
   \author Satofumi KAMIMURA
 
-  $Id$
+  $Id: ReleaseDataFile.cpp 263 2009-01-30 14:48:10Z satofumi $
 */
 
-#include <stddef.h>
 #include "ReleaseDataFile.h"
 #include "ArchiveConfig.h"
 #include "RrdaDecoder.h"
 #include "AnimationPattern.h"
+#include <cstddef>
+
+using namespace std;
 
 
-bool releaseDataFile(const ArchiveConfig& archive_config, size_t cell_max) {
-
+bool releaseDataFile(const ArchiveConfig& archive_config, size_t cell_max)
+{
   RrdaDecoder decoder(archive_config.getReleaseName(),
                       archive_config.getRrdaKey());
 
@@ -29,13 +31,13 @@ bool releaseDataFile(const ArchiveConfig& archive_config, size_t cell_max) {
   for (size_t i = 0; i < n; ++i) {
 
     // 通常データ
-    const std::string normal_value = archive_config.getNormalData(tags[i]);
+    const string normal_value = archive_config.getNormalData(tags[i]);
     if (! normal_value.empty()) {
       decoder.setNormalData(tags[i], normal_value);
     }
 
     // 制限データ
-    const std::string restrict_value = archive_config.getRestrictData(tags[i]);
+    const string restrict_value = archive_config.getRestrictData(tags[i]);
     if (! restrict_value.empty()) {
       decoder.setRestrictData(tags[i], restrict_value);
     }
@@ -45,7 +47,7 @@ bool releaseDataFile(const ArchiveConfig& archive_config, size_t cell_max) {
   for (size_t i = 0; i < cell_max; ++i) {
 
     AnimationCellTag cell_tags(i);
-    const std::string value =
+    const string value =
       archive_config.getNormalData(cell_tags.simple_tag);
     if (! value.empty()) {
       decoder.setNormalData(cell_tags.simple_tag, value);
@@ -55,4 +57,3 @@ bool releaseDataFile(const ArchiveConfig& archive_config, size_t cell_max) {
 
   return decoder.release();
 }
-
