@@ -7,17 +7,19 @@
 
   \author Satofumi KAMIMURA
 
-  $Id$
+  $Id: ReleaseDataFile.h 263 2009-01-30 14:48:10Z satofumi $
 */
 
+#include <cstddef>
+
 class ArchiveConfig;
 
 
 /*!
   \brief リリースデータ生成
 
-  \param archive_config [i] アーカイブ管理オブジェクト
-  \param cell_max [i] アニメーションのセル枚数
+  \param[in] archive_config アーカイブ管理オブジェクト
+  \param[in] cell_max アニメーションのセル枚数
 
   \retval true 正常
   \retval false エラー
