@@ -7,7 +7,7 @@
 
   \author Satofumi KAMIMURA
 
-  $Id$
+  $Id: ReleaseDialog.h 261 2009-01-22 06:48:10Z satofumi $
 */
 
 #include "ui_ReleaseDialogForm.h"
@@ -18,7 +18,8 @@ class ArchiveConfig;
 /*!
   \brief リリースダイアログ管理クラス
 */
-class ReleaseDialog : public QDialog, private Ui::ReleaseDialog {
+class ReleaseDialog : public QDialog, private Ui::ReleaseDialog
+{
   Q_OBJECT;
 
   ReleaseDialog(const ReleaseDialog& rhs);
@@ -32,7 +33,7 @@ public:
   /*!
     \brief コンストラクタ
 
-    \param parent [i] 親ウィジット
+    \param[in] parent 親ウィジット
   */
   explicit ReleaseDialog(QDialog* parent = 0);
   ~ReleaseDialog(void);
@@ -41,8 +42,8 @@ public:
   /*!
     \brief 初期値の設定
 
-    \param release_file [i] リリースファイル名
-    \param rrda_key [i] RRDA キー
+    \param[in] release_file リリースファイル名
+    \param[in] rrda_key RRDA キー
   */
   void setDefaultValue(const std::string& release_file,
                        const std::string& rrda_key);
@@ -52,8 +53,8 @@ signals:
   /*!
     \brief リリース [signal]
 
-    \param file [o] リリースファイル名
-    \param key [o] RRDA キー
+    \param[out] file リリースファイル名
+    \param[out] key RRDA キー
   */
   void release(const QString& file, const QString& key);
 };
