@@ -1,5 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="ja_JP">
+<!DOCTYPE TS>
+<TS version="2.0" language="ja_JP">
 <context>
     <name>PatternRegisterWidgetForm</name>
     <message>
@@ -46,7 +47,7 @@
 <context>
     <name>QLabel</name>
     <message>
-        <location filename="../qtmclock/ThemeClockDraw.cpp" line="77"/>
+        <location filename="../qtmclock/ThemeClockDraw.cpp" line="81"/>
         <source>Drop theme file in this form.</source>
         <translation>テーマファイルを、このフォームにドロップして下さい.</translation>
     </message>
@@ -72,397 +73,405 @@
 <context>
     <name>ThemeConfigWindow</name>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="18"/>
+        <location filename="ThemeConfigWindowForm.ui" line="19"/>
         <source>Theme Config</source>
         <translation>Theme Config</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="317"/>
+        <location filename="ThemeConfigWindowForm.ui" line="285"/>
         <source>long hand</source>
         <translation>長針</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="294"/>
+        <location filename="ThemeConfigWindowForm.ui" line="262"/>
         <source>base</source>
         <translation>ベース</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="309"/>
+        <location filename="ThemeConfigWindowForm.ui" line="277"/>
         <source>short hand</source>
         <translation>短針</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="325"/>
+        <location filename="ThemeConfigWindowForm.ui" line="293"/>
         <source>second hand</source>
         <translation>秒針</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="334"/>
+        <location filename="ThemeConfigWindowForm.ui" line="302"/>
         <source>digital character</source>
         <translation>デジタル文字</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="664"/>
+        <location filename="ThemeConfigWindowForm.ui" line="607"/>
         <source>toolbar</source>
         <translation>ツールバー</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="341"/>
+        <location filename="ThemeConfigWindowForm.ui" line="309"/>
         <source>hour</source>
         <translation>時</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="365"/>
+        <location filename="ThemeConfigWindowForm.ui" line="333"/>
         <source>minute</source>
         <translation>分</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="381"/>
+        <location filename="ThemeConfigWindowForm.ui" line="349"/>
         <source>second</source>
         <translation>秒</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="397"/>
+        <location filename="ThemeConfigWindowForm.ui" line="365"/>
         <source>AM/PM</source>
         <translation>AM/PM</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="357"/>
+        <location filename="ThemeConfigWindowForm.ui" line="325"/>
         <source>colon</source>
         <translation>コロン</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="284"/>
+        <location filename="ThemeConfigWindowForm.ui" line="252"/>
         <source>Node</source>
         <translation>項目</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="289"/>
+        <location filename="ThemeConfigWindowForm.ui" line="257"/>
         <source>Value</source>
         <translation>画像</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="682"/>
+        <location filename="ThemeConfigWindowForm.ui" line="625"/>
         <source>Ctrl+N</source>
         <translation>Ctrl+N</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1617"/>
+        <location filename="ThemeConfigWindow.cpp" line="1622"/>
         <source>Create a new config file.</source>
         <translation>設定ファイルの新規作成.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="694"/>
+        <location filename="ThemeConfigWindowForm.ui" line="637"/>
         <source>Ctrl+O</source>
         <translation>Ctrl+O</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1621"/>
+        <location filename="ThemeConfigWindow.cpp" line="1626"/>
         <source>Open an exist config file.</source>
         <translation>設定ファイルを開く.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="706"/>
+        <location filename="ThemeConfigWindowForm.ui" line="649"/>
         <source>Ctrl+S</source>
         <translation>Ctrl+S</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1625"/>
+        <location filename="ThemeConfigWindow.cpp" line="1630"/>
         <source>Save the config file to disk.</source>
         <translation>設定ファイルの保存.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="152"/>
+        <location filename="ThemeConfigWindowForm.ui" line="129"/>
         <source>hands&apos;s center are samve.</source>
         <translation>長針、短針、秒針の中心を揃える.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="302"/>
+        <location filename="ThemeConfigWindowForm.ui" line="270"/>
         <source>analog parts</source>
         <translation>アナログ部品</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="40"/>
+        <location filename="ThemeConfigWindowForm.ui" line="33"/>
         <source>Play / Stop</source>
         <translation>再生 / 停止</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="617"/>
+        <location filename="ThemeConfigWindowForm.ui" line="577"/>
         <source>File (&amp;F)</source>
         <translation>ファイル (&amp;F)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="630"/>
+        <location filename="ThemeConfigWindowForm.ui" line="590"/>
         <source>Edit (&amp;E)</source>
         <translation>編集 (&amp;E)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="636"/>
+        <location filename="ThemeConfigWindowForm.ui" line="596"/>
         <source>Help (&amp;H)</source>
         <translation>ヘルプ (&amp;H)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1616"/>
+        <location filename="ThemeConfigWindow.cpp" line="1621"/>
         <source>New</source>
         <translation>新規作成</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1620"/>
+        <location filename="ThemeConfigWindow.cpp" line="1625"/>
         <source>Open</source>
         <translation>開く</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1624"/>
+        <location filename="ThemeConfigWindow.cpp" line="1629"/>
         <source>Save</source>
         <translation>保存</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="711"/>
+        <location filename="ThemeConfigWindowForm.ui" line="654"/>
         <source>Release (&amp;R)</source>
         <translation>リリース (&amp;R)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="716"/>
+        <location filename="ThemeConfigWindowForm.ui" line="659"/>
         <source>Exit (&amp;Q)</source>
         <translation>終了 (&amp;Q)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="719"/>
+        <location filename="ThemeConfigWindowForm.ui" line="662"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="724"/>
+        <location filename="ThemeConfigWindowForm.ui" line="667"/>
         <source>Save as</source>
         <translation>名前を付けて保存</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="729"/>
+        <location filename="ThemeConfigWindowForm.ui" line="672"/>
         <source>Preview (&amp;R)</source>
         <translation>プレビュー (&amp;R)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="732"/>
+        <location filename="ThemeConfigWindowForm.ui" line="675"/>
         <source>Ctrl+R</source>
         <translation>Ctrl+R</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="737"/>
+        <location filename="ThemeConfigWindowForm.ui" line="680"/>
         <source>About (&amp;A)</source>
         <translation>このアプリケーションについて (&amp;A)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="348"/>
+        <location filename="ThemeConfigWindowForm.ui" line="316"/>
         <source>h2</source>
         <translation>位置 (1の位)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="372"/>
+        <location filename="ThemeConfigWindowForm.ui" line="340"/>
         <source>m2</source>
         <translation>位置 (100 の位)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="388"/>
+        <location filename="ThemeConfigWindowForm.ui" line="356"/>
         <source>s2</source>
         <translation>位置 (1の位)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="203"/>
+        <location filename="ThemeConfigWindowForm.ui" line="172"/>
         <source>blink digital colon.</source>
         <translation>デジタル文字のコロンを点滅させる.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="213"/>
+        <location filename="ThemeConfigWindowForm.ui" line="182"/>
         <source>show digital second.</source>
         <translation>デジタル文字の秒を表示する.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1702"/>
+        <location filename="ThemeConfigWindow.cpp" line="1707"/>
         <source>Open archive list file.</source>
         <translation>設定ファイルを開く.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1744"/>
+        <location filename="ThemeConfigWindow.cpp" line="1709"/>
+        <location filename="ThemeConfigWindow.cpp" line="1749"/>
         <source>archive list (*.txt)</source>
         <translation>設定ファイル (*.txt)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1742"/>
+        <location filename="ThemeConfigWindow.cpp" line="1747"/>
         <source>Save archive list file.</source>
         <translation>設定ファイルの保存.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="679"/>
+        <location filename="ThemeConfigWindowForm.ui" line="622"/>
         <source>New (&amp;N)</source>
         <translation>新規作成 (&amp;N)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="691"/>
+        <location filename="ThemeConfigWindowForm.ui" line="634"/>
         <source>Open (&amp;O)</source>
         <translation>開く (&amp;O)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="703"/>
+        <location filename="ThemeConfigWindowForm.ui" line="646"/>
         <source>Save (&amp;S)</source>
         <translation>保存 (&amp;S)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="515"/>
+        <location filename="ThemeConfigWindowForm.ui" line="483"/>
         <source>Parts image</source>
         <translation>部品画像の更新</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="525"/>
+        <location filename="ThemeConfigWindowForm.ui" line="493"/>
         <source>...</source>
         <translation>...</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="162"/>
+        <location filename="ThemeConfigWindowForm.ui" line="139"/>
         <source>show analog second.</source>
         <translation>秒針を表示する.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="2028"/>
+        <location filename="ThemeConfigWindow.cpp" line="2034"/>
         <source>Open parts file.</source>
         <translation>部品ファイルを開く.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="2030"/>
+        <location filename="ThemeConfigWindow.cpp" line="2036"/>
         <source>parts file (*.png)</source>
         <translation>部品ファイル (*.png)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1823"/>
+        <location filename="ThemeConfigWindow.cpp" line="1828"/>
         <source>About qtmclock_config</source>
         <translation>qtmclock_config について</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1827"/>
+        <location filename="ThemeConfigWindow.cpp" line="1829"/>
         <source>&lt;h2&gt;Qtmclock Config&lt;/h2&gt;&lt;p&gt;Theme making tool for Qtmclock.&lt;/p&gt;&lt;p&gt;Report bugs to &amp;lt;satofumi@users.sourceforge.jp&amp;gt;&lt;/p&gt;</source>
         <translation>&lt;h2&gt;Qtmclock Config&lt;/h2&gt;&lt;p&gt;Qtmclock 用のテーマ作成ツール&lt;/p&gt;&lt;p&gt;バグの報告先 &amp;lt;satofumi@users.sourceforge.jp&amp;gt;&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="132"/>
+        <location filename="ThemeConfigWindowForm.ui" line="109"/>
         <source>Analog Clock</source>
         <translation>アナログ時計</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="190"/>
+        <location filename="ThemeConfigWindowForm.ui" line="120"/>
+        <location filename="ThemeConfigWindowForm.ui" line="159"/>
         <source>Clock Settings</source>
         <translation>描画設定</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="249"/>
+        <location filename="ThemeConfigWindowForm.ui" line="210"/>
         <source>Calendar</source>
         <translation>カレンダー</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="255"/>
+        <location filename="ThemeConfigWindowForm.ui" line="216"/>
         <source>Calendar Settings</source>
         <translation>描画設定</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="406"/>
+        <location filename="ThemeConfigWindowForm.ui" line="232"/>
+        <source>show zero digit.</source>
+        <oldsource>show zero digit</oldsource>
+        <translation>数値の 10 の位がゼロのときにも表示する.</translation>
+    </message>
+    <message>
+        <location filename="ThemeConfigWindowForm.ui" line="374"/>
         <source>calendar</source>
         <translation>カレンダー</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="420"/>
+        <location filename="ThemeConfigWindowForm.ui" line="388"/>
         <source>month</source>
         <translation>月</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="444"/>
+        <location filename="ThemeConfigWindowForm.ui" line="412"/>
         <source>day</source>
         <translation>日</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="477"/>
+        <location filename="ThemeConfigWindowForm.ui" line="445"/>
         <source>day of the week</source>
         <translation>曜日</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="264"/>
+        <location filename="ThemeConfigWindowForm.ui" line="225"/>
         <source>show month.</source>
         <translation>月を表示する.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="413"/>
+        <location filename="ThemeConfigWindowForm.ui" line="381"/>
         <source>number</source>
         <translation>数値</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="435"/>
+        <location filename="ThemeConfigWindowForm.ui" line="403"/>
         <source>month_separator</source>
         <translation>区切り文字</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="451"/>
+        <location filename="ThemeConfigWindowForm.ui" line="419"/>
         <source>c_d2</source>
         <translation>位置 (1 の位)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="459"/>
+        <location filename="ThemeConfigWindowForm.ui" line="427"/>
         <source>day_separator</source>
         <translation>区切り文字</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="469"/>
+        <location filename="ThemeConfigWindowForm.ui" line="437"/>
         <source>separator</source>
         <translation>区切り文字</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="427"/>
+        <location filename="ThemeConfigWindowForm.ui" line="395"/>
         <source>c_m2</source>
         <translation>位置 (1 の位)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="486"/>
+        <location filename="ThemeConfigWindowForm.ui" line="454"/>
         <source>additional</source>
         <translation>追加部品</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="493"/>
+        <location filename="ThemeConfigWindowForm.ui" line="461"/>
         <source>near</source>
         <translation>手前</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="107"/>
+        <location filename="ThemeConfigWindowForm.ui" line="92"/>
         <source>Placement</source>
         <translation>配置</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="502"/>
+        <location filename="ThemeConfigWindowForm.ui" line="470"/>
         <source>animation</source>
         <translation>アニメーション</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="545"/>
+        <location filename="ThemeConfigWindowForm.ui" line="505"/>
         <source>Animation</source>
         <translation>アニメーション</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="196"/>
+        <location filename="ThemeConfigWindowForm.ui" line="165"/>
         <source>show digital colon.</source>
         <translation>デジタル文字のコロンを表示する.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="184"/>
+        <location filename="ThemeConfigWindowForm.ui" line="153"/>
         <source>Digital Clock</source>
         <translation>デジタル時計</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="223"/>
+        <location filename="ThemeConfigWindowForm.ui" line="192"/>
         <source>show AM/PM.</source>
         <translation>AM / PM を表示する.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="230"/>
+        <location filename="ThemeConfigWindowForm.ui" line="199"/>
         <source>show digital above analog hands.</source>
         <translation>デジタル表示をアナログ針よりも手前に表示する.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="577"/>
+        <location filename="ThemeConfigWindowForm.ui" line="537"/>
         <source>Add Pattern</source>
         <translation>パターンの追加</translation>
     </message>
